@@ -54,15 +54,16 @@
 #'
 #' @examples
 #' \donttest{
+#' library(LipidMSdata)
 #' dbs <- assignDB()
 #'
-#' candidates <- findCandidates(MS1 = LipidMS::MS1_neg$peaklist,
+#' candidates <- findCandidates(MS1 = MS1_neg$peaklist,
 #' db = dbs$pgdb, ppm = 10, rt = c(0, 2000), adducts = c("M-H"),
 #' rttol = 10, rawData = MS1_neg$rawScans, coelCutoff = 0.8)
 #'
-#' MSMS <- rbind(LipidMS::MSMS1_neg$peaklist, LipidMS::MSMS2_neg$peaklist)
-#' rawData <- rbind(LipidMS::MS1_neg$rawScans, LipidMS::MSMS1_neg$rawScans,
-#' LipidMS::MSMS2_neg$rawScans)
+#' MSMS <- rbind(MSMS1_neg$peaklist, MSMS2_neg$peaklist)
+#' rawData <- rbind(MS1_neg$rawScans, MSMS1_neg$rawScans,
+#' MSMS2_neg$rawScans)
 #' coelfrags <- coelutingFrags(candidates$RT, MSMS, rttol = 10, rawData = rawData,
 #' coelCutoff = 0.8)
 #'
@@ -71,16 +72,17 @@
 #' ftype = c("F", "F", "NL"), ppm = 10, dbs = dbs)
 #' }
 #' \donttest{
+#' library(LipidMSdata)
 #' dbs <- assignDB()
 #'
-#' candidates <- findCandidates(MS1 = LipidMS::MS1$peaktable,
+#' candidates <- findCandidates(MS1 = MS1_neg$peaktable,
 #' db = dbs$pgdb,
 #' ppm = 10, rt = c(0, 2000), adducts = c("M-H"),
 #' rttol = 10, rawData = MS1$rawData, coelCutoff = 0.8)
 #'
-#' MSMS <- rbind(LipidMS::MSMS1$peaktable, LipidMS::MSMS2$peaktable)
-#' rawData <- rbind(LipidMS::MS1$rawData, LipidMS::MSMS1$rawData,
-#' LipidMS::MSMS2$rawData)
+#' MSMS <- rbind(MSMS1_neg$peaktable, MSMS2_neg$peaktable)
+#' rawData <- rbind(MS1_neg$rawData, MSMS1_neg$rawData,
+#' MSMS2_neg$rawData)
 #' coelfrags <- coelutingFrags(candidates$RT, MSMS, rttol = 10, rawData = rawData,
 #' coelCutoff = 0.8)
 #'
@@ -103,7 +105,7 @@ checkClass <- function(candidates, coelfrags, clfrags, ftype, clrequisites,
       if (ftype[i] == "F"){
         classf <- lapply(coelfrags, function(x){
           filtermsms(x, as.numeric(clfrags[i]), ppm)})
-        verified[,i] <- unlist(lapply(classf, function(x) nrow(x) > 0))
+        verified[,i] <- unlist(lapply(classf, function(x) {if(is.data.frame(x)){nrow(x) > 0}else {FALSE}}))
         allfragments <- Map(rbind, classf, allfragments)
       } else if (ftype[i] == "NL") {
         classf <- list()
@@ -111,7 +113,7 @@ checkClass <- function(candidates, coelfrags, clfrags, ftype, clrequisites,
           f <- filtermsms(coelfrags[[c]], candidates$m.z[c]-as.numeric(clfrags[i]), ppm)
           classf[[c]] <- f
         }
-        verified[,i] <- unlist(lapply(classf, function(x) nrow(x) > 0))
+        verified[,i] <- unlist(lapply(classf, function(x) {if(is.data.frame(x)){nrow(x) > 0}else {FALSE}}))
         allfragments <- Map(rbind, classf, allfragments)
       } else if (ftype[i] == "BB"){
         db <- dbs[[paste(unlist(strsplit(clfrags[i], "_"))[1], "db", sep="")]]
@@ -124,7 +126,7 @@ checkClass <- function(candidates, coelfrags, clfrags, ftype, clrequisites,
                           ppm)
           classf[[c]] <- f
         }
-        verified[,i] <- unlist(lapply(classf, function(x) nrow(x) > 0))
+        verified[,i] <- unlist(lapply(classf, function(x) {if(is.data.frame(x)){nrow(x) > 0}else {FALSE}}))
         allfragments <- Map(rbind, classf, allfragments)
       }
     }
